@@ -16,12 +16,12 @@ class ReqIFExport:
         output_reqif_root: str,
     ):
         Path(output_reqif_root).mkdir(parents=True, exist_ok=True)
-        output_file = os.path.join(output_reqif_root, "output.reqif")
+        output_file_path: str = os.path.join(output_reqif_root, "output.reqif")
 
         reqif_bundle = SDocToReqIFObjectConverter.convert_document_tree(
             document_tree=document_tree
         )
-        reqif_content = ReqIFUnparser.unparse(reqif_bundle)
+        reqif_content: str = ReqIFUnparser.unparse(reqif_bundle)
 
-        with open(output_file, "w", encoding="utf8") as output_file:
+        with open(output_file_path, "w", encoding="utf8") as output_file:
             output_file.write(reqif_content)
