@@ -69,6 +69,7 @@ DocumentConfig[noskipws]:
   ('OPTIONS:' '\n'
     ('  MARKUP: ' (markup = MarkupChoice) '\n')?
     ('  AUTO_LEVELS: ' (auto_levels = AutoLevelsChoice) '\n')?
+    ('  REQUIREMENT_STYLE: ' (requirement_style = RequirementStyleChoice) '\n')?
   )?
 ;
 
@@ -76,6 +77,10 @@ MarkupChoice[noskipws]:
   'RST' | 'Text' | 'HTML'
 ;
 
+RequirementStyleChoice[noskipws]:
+  'Inline' | 'Table'
+;
+
 AutoLevelsChoice[noskipws]:
   'On' | 'Off'
 ;
