@@ -8,6 +8,8 @@ from strictdoc.backend.sdoc.models.document_grammar import (
 from strictdoc.backend.sdoc.models.node import Node
 from strictdoc.backend.sdoc.models.reference import Reference
 
+MULTILINE_WORD_THRESHOLD = 6
+
 
 class RequirementContext:
     def __init__(self):
@@ -63,14 +65,14 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
         uid = None
         level = None
         status = None
-        tags = None
-        references = []
+        tags: Optional[List[str]] = None
+        references: List[Reference] = []
         title = None
         statement = None
         statement_multiline = None
         rationale = None
         rationale_multiline = None
-        comments: [RequirementComment] = []
+        comments: List[RequirementComment] = []
 
         ordered_fields_lookup: OrderedDict[
             str, List[RequirementField]
@@ -91,7 +93,11 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
         if "TAGS" in ordered_fields_lookup:
             tags = ordered_fields_lookup["TAGS"][0].field_value.split(", ")
         if "REFS" in ordered_fields_lookup:
-            references = ordered_fields_lookup["REFS"][0].field_value_references
+            references_opt: Optional[List[Reference]] = ordered_fields_lookup[
+                "REFS"
+            ][0].field_value_references
+            assert references_opt is not None
+            references = references_opt
         if "TITLE" in ordered_fields_lookup:
             title = ordered_fields_lookup["TITLE"][0].field_value
         if "STATEMENT" in ordered_fields_lookup:
@@ -133,7 +139,7 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
         )
         self.level: Optional[str] = level
         self.status = status
-        self.tags: Optional[str] = tags
+        self.tags: Optional[List[str]] = tags
 
         assert isinstance(references, List)
         self.references: List[Reference] = references
@@ -161,7 +167,7 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
         self.ordered_fields_lookup: OrderedDict[
             str, List[RequirementField]
         ] = ordered_fields_lookup
-        self.ng_level = None
+        self.ng_level: Optional[int] = None
         self.ng_document_reference: Optional[DocumentReference] = None
         self.context = RequirementContext()
 
@@ -194,6 +200,11 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
     def document(self):
         return self.ng_document_reference.get_document()
 
+    def is_inline_requirement(self):
+        return (
+            self.ng_document_reference.get_document().config.is_inline_requirements()  # noqa: E501
+        )
+
     def get_requirement_references(self):
         if not self.references or len(self.references) == 0:
             return []
@@ -229,11 +240,31 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
             for single_field in requirement_field:
                 yield single_field
 
-    def enumerate_meta_fields(self):
+    def enumerate_meta_fields(
+        self, skip_single_lines=False, skip_multi_lines=False
+    ):
         for field in self.fields:
             if field.field_name in RESERVED_NON_META_FIELDS:
                 continue
-            yield field.field_name, field.field_value
+            meta_field_value = (
+                field.field_value
+                if field.field_value
+                else field.field_value_multiline
+            )
+            if (
+                len(meta_field_value.splitlines()) > 1
+                or len(meta_field_value.split(" ")) > MULTILINE_WORD_THRESHOLD
+            ):
+                is_single_line_field = False
+            else:
+                is_single_line_field = True
+
+            if is_single_line_field and skip_single_lines:
+                continue
+            if (not is_single_line_field) and skip_multi_lines:
+                continue
+
+            yield field.field_name, meta_field_value
 
     def dump_fields(self):
         return ", ".join(
@@ -249,7 +280,6 @@ class Requirement(Node):  # pylint: disable=too-many-instance-attributes
 class CompositeRequirement(Requirement):
     def __init__(self, parent, **fields):
         super().__init__(parent, **fields)
-        self.ng_sections = []
         self.ng_document_reference: Optional[DocumentReference] = None
         self.ng_has_requirements = False
 
