@@ -7,6 +7,8 @@ from strictdoc.backend.sdoc.error_handling import StrictDocSemanticError
 from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.backend.sdoc.models.document_config import DocumentConfig
 from strictdoc.backend.sdoc.models.document_grammar import DocumentGrammar
+from strictdoc.backend.sdoc.models.fragment import Fragment
+from strictdoc.backend.sdoc.models.fragment_from_file import FragmentFromFile
 from strictdoc.backend.sdoc.models.requirement import (
     CompositeRequirement,
     Requirement,
@@ -22,6 +24,7 @@ class ParseContext:
         self.document_grammar: DocumentGrammar = DocumentGrammar.create_default(
             None
         )
+        self.current_include_parent = None
 
 
 class SDocParsingProcessor:
@@ -47,7 +50,7 @@ class SDocParsingProcessor:
         section.ng_document_reference = self.parse_context.document_reference
 
         if self.parse_context.document_config.auto_levels:
-            if section.level:
+            if section.level and section.level != "None":
                 print(
                     "warning: [SECTION].LEVEL field is provided. "
                     "This contradicts to the option "
@@ -63,11 +66,36 @@ class SDocParsingProcessor:
                     f"Section: {section}"
                 )
 
-        if section.parent.ng_level is None:
-            SDocParsingProcessor._resolve_parents(section)
-        section.ng_level = section.parent.ng_level + 1
+        self._resolve_parents(section)
         assert section.ng_level > 0
-        section.parent.ng_sections.append(section)
+
+    def process_include(self, include: FragmentFromFile):
+        # pylint: disable=import-outside-toplevel
+        from strictdoc.backend.sdoc.reader import (
+            SDIReader,
+        )  # can't import globally or else module loop ensues
+
+        self._resolve_parents(include)
+        self.parse_context.current_include_parent = include.parent
+
+        reader = SDIReader()
+        fragment = reader.read_from_file(
+            file_path=include.file, context=self.parse_context
+        )
+        assert isinstance(fragment, Fragment)
+
+        parent_section_contents = include.parent.section_contents
+        index = parent_section_contents.index(include)
+        before = parent_section_contents[:index]
+        index = (
+            index + 1
+        )  # black and flake8 fight to put a space before ':' otherwise
+        after = parent_section_contents[index:]
+
+        include.parent.section_contents = []
+        include.parent.section_contents.extend(before)
+        include.parent.section_contents.extend(fragment.section_contents)
+        include.parent.section_contents.extend(after)
 
     def process_composite_requirement(
         self, composite_requirement: CompositeRequirement
@@ -94,32 +122,23 @@ class SDocParsingProcessor:
         )
 
         if isinstance(composite_requirement.parent, Section):
-            if composite_requirement.parent.ng_level is None:
-                SDocParsingProcessor._resolve_parents(composite_requirement)
-            composite_requirement.ng_level = (
-                composite_requirement.parent.ng_level + 1
-            )
-            composite_requirement.parent.ng_sections.append(
-                composite_requirement
-            )
+            self._resolve_parents(composite_requirement)
         elif isinstance(composite_requirement.parent, CompositeRequirement):
-            if composite_requirement.parent.ng_level is None:
-                SDocParsingProcessor._resolve_parents(composite_requirement)
+            self._resolve_parents(composite_requirement)
             assert composite_requirement.parent.ng_level
-            composite_requirement.ng_level = (
-                composite_requirement.parent.ng_level + 1
-            )
         elif isinstance(composite_requirement.parent, Document):
             composite_requirement.ng_level = 1
+        elif isinstance(composite_requirement.parent, Fragment):
+            composite_requirement.ng_level = (
+                self.parse_context.current_include_parent.ng_level + 1
+            )
         else:
             raise NotImplementedError
 
         # TODO: there is now walking up the parents 2 times
         # (ng_levels and here).
         cursor = composite_requirement.parent
-        while (
-            not isinstance(cursor, Document) and not cursor.ng_has_requirements
-        ):
+        while not self.is_top_level(cursor) and not cursor.ng_has_requirements:
             cursor.ng_has_requirements = True
             cursor = cursor.parent
 
@@ -158,51 +177,70 @@ class SDocParsingProcessor:
         )
 
         if isinstance(requirement.parent, Section):
-            if requirement.parent.ng_level is None:
-                SDocParsingProcessor._resolve_parents(requirement)
-            requirement.ng_level = requirement.parent.ng_level + 1
+            self._resolve_parents(requirement)
         elif isinstance(requirement.parent, CompositeRequirement):
-            if requirement.parent.ng_level is None:
-                SDocParsingProcessor._resolve_parents(requirement)
-            requirement.ng_level = requirement.parent.ng_level + 1
+            self._resolve_parents(requirement)
         elif isinstance(requirement.parent, Document):
             requirement.ng_level = 1
+        elif isinstance(requirement.parent, Fragment):
+            requirement.ng_level = (
+                self.parse_context.current_include_parent.ng_level + 1
+            )
         else:
             raise NotImplementedError
 
         # TODO: there is now walking up the parents 2 times (ng_levels
         # and here).
         cursor = requirement.parent
-        while (
-            not isinstance(cursor, Document) and not cursor.ng_has_requirements
-        ):
+        while not self.is_top_level(cursor) and not cursor.ng_has_requirements:
             cursor.ng_has_requirements = True
+            if isinstance(cursor, Fragment):
+                break
             cursor = cursor.parent
 
-    @staticmethod
-    def process_free_text(free_text):
+    def process_free_text(self, free_text):
         if isinstance(free_text.parent, Section):
-            if free_text.parent.ng_level is None:
-                SDocParsingProcessor._resolve_parents(free_text)
-            free_text.ng_level = free_text.parent.ng_level + 1
+            self._resolve_parents(free_text)
         elif isinstance(free_text.parent, CompositeRequirement):
-            if free_text.parent.ng_level is None:
-                SDocParsingProcessor._resolve_parents(free_text)
-            free_text.ng_level = free_text.parent.ng_level + 1
+            self._resolve_parents(free_text)
         elif isinstance(free_text.parent, Document):
             free_text.ng_level = 1
+        elif isinstance(free_text.parent, Fragment):
+            free_text.ng_level = (
+                self.parse_context.current_include_parent.ng_level + 1
+            )
         else:
             raise NotImplementedError
 
+    def process_fragment(self, fragment: Fragment):
+        pass
+
+    @staticmethod
+    def is_top_level(node):
+        return isinstance(node, Document)
+
     # During parsing, it is often the case that the node's parents do not have
     # their levels resolved yet. We go up the parent chain and resolve all of
     # the parents manually.
-    @staticmethod
-    def _resolve_parents(node):
+    def _resolve_parents(self, node):
         parents_to_resolve_level = []
-        cursor = node.parent
+        cursor = node
         while cursor.ng_level is None:
+            if isinstance(cursor.parent, Fragment):
+                cursor.parent = self.parse_context.current_include_parent
+                continue
             parents_to_resolve_level.append(cursor)
             cursor = cursor.parent
+        cursor_level = cursor.ng_level
+
+        section_with_none_level = cursor.level == "None"
         for parent_idx, parent in enumerate(reversed(parents_to_resolve_level)):
-            parent.ng_level = cursor.ng_level + parent_idx + 1
+            parent.ng_level = cursor_level + parent_idx + 1
+            if isinstance(parent, Section):
+                if section_with_none_level:
+                    parent.level = "None"
+                elif parent.level == "None":
+                    section_with_none_level = True
+        node.ng_level = node.parent.ng_level + 1
+        if section_with_none_level:
+            node.level = "None"
