@@ -52,12 +52,17 @@ class SDWriter:
 
             markup = document_config.markup
             auto_levels_specified = document_config.ng_auto_levels_specified
+            requirement_style = document_config.requirement_style
 
-            if markup or auto_levels_specified:
+            if (
+                markup is not None
+                or auto_levels_specified
+                or requirement_style is not None
+            ):
                 output += "OPTIONS:"
                 output += "\n"
 
-                if markup:
+                if markup is not None:
                     output += "  MARKUP: "
                     output += markup
                     output += "\n"
@@ -67,6 +72,11 @@ class SDWriter:
                     output += "On" if document_config.auto_levels else "Off"
                     output += "\n"
 
+                if requirement_style is not None:
+                    output += "  REQUIREMENT_STYLE: "
+                    output += requirement_style
+                    output += "\n"
+
         document_grammar = document.grammar
         if not document_grammar.is_default:
             output += "\n[GRAMMAR]\n"
