@@ -1,7 +1,7 @@
 import collections
 import os
+from typing import Dict, Optional, Set, List
 
-from strictdoc.cli.cli_arg_parser import ExportCommandConfig
 from strictdoc.helpers.sorting import alphanumeric_sort
 
 
@@ -38,16 +38,16 @@ class File(FileOrFolderEntry):
     def get_full_path(self):
         return self.full_path
 
-    def get_level(self):
+    def get_level(self) -> int:
         return self.level
 
-    def get_file_name(self):
+    def get_file_name(self) -> str:
         return os.path.basename(self.full_path)
 
-    def get_folder_path(self):
+    def get_folder_path(self) -> str:
         return os.path.dirname(self.full_path)
 
-    def mount_folder(self):
+    def mount_folder(self) -> str:
         return os.path.basename(os.path.dirname(self.root_path))
 
 
@@ -64,7 +64,7 @@ class Folder(FileOrFolderEntry):
         self.has_sdoc_content = False
 
     def __repr__(self):
-        return f"FileTree: (root_path: {self.root_path}, files: {self.files})"
+        return f"Folder: (root_path: {self.root_path}, files: {self.files})"
 
     def is_folder(self):
         return True
@@ -101,13 +101,13 @@ class Folder(FileOrFolderEntry):
 
 
 class FileTree:
-    def __init__(self, root_folder_or_file):
+    def __init__(self, *, root_folder_or_file):
         self.root_folder_or_file = root_folder_or_file
 
     @staticmethod
     def create_single_file_tree(root_path):
         single_file = File(0, root_path)
-        return FileTree(single_file)
+        return FileTree(root_folder_or_file=single_file)
 
     def iterate(self):
         file_tree_mount_folder = self.root_folder_or_file.mount_folder()
@@ -136,23 +136,33 @@ class FileTree:
                     reversed(file_tree_or_file.subfolder_trees)
                 )
 
+    def __str__(self):
+        dump = ""
+        for file_or_tree in self.iterate():
+            dump += str(file_or_tree)
+            dump += "\n"
+        return dump
+
+    def __repr__(self):
+        return self.__str__()
+
 
 class FileFinder:
     @staticmethod
     def find_files_with_extensions(
-        root_path, config: ExportCommandConfig, extensions
+        *, root_path: str, ignored_dirs: List[str], extensions: Set[str]
     ):
         assert os.path.isdir(root_path)
         assert os.path.isabs(root_path)
         assert isinstance(extensions, set)
 
-        root_level = root_path.count(os.sep)
+        root_level: int = root_path.count(os.sep)
 
-        root_folder = Folder(root_path, 0)
-        folder_map = {root_path: root_folder}
+        root_folder: Folder = Folder(root_path, 0)
+        folder_map: Dict[str, Folder] = {root_path: root_folder}
 
         for current_root_path, dirs, files in os.walk(root_path, topdown=True):
-            if current_root_path == config.output_dir:
+            if current_root_path in ignored_dirs:
                 dirs[:] = []
                 continue
 
@@ -167,7 +177,7 @@ class FileFinder:
             ]
             dirs.sort(key=alphanumeric_sort)
 
-            current_root_path_level = (
+            current_root_path_level: int = (
                 current_root_path.count(os.sep) - root_level
             )
 
@@ -198,10 +208,10 @@ class FileFinder:
             # top-down search assumes we have seen the parent before.
             assert current_parent_path in folder_map
 
-            current_parent_folder = folder_map[current_parent_path]
+            current_parent_folder: Folder = folder_map[current_parent_path]
             current_tree.set_parent_folder(current_parent_folder)
             if current_tree.has_sdoc_content:
-                parent_folder_cursor = current_parent_folder
+                parent_folder_cursor: Optional[Folder] = current_parent_folder
                 while (
                     parent_folder_cursor
                     and not parent_folder_cursor.has_sdoc_content
@@ -211,7 +221,9 @@ class FileFinder:
 
             current_parent_folder.add_subfolder_tree(current_tree)
 
-        file_tree_structure = FileTree(folder_map[root_path])
+        file_tree_structure = FileTree(
+            root_folder_or_file=folder_map[root_path]
+        )
         return file_tree_structure
 
 
