@@ -1,7 +1,6 @@
 from jinja2 import Environment, PackageLoader, StrictUndefined
 
 from strictdoc.export.html.document_type import DocumentType
-from strictdoc.export.html.renderers.markup_renderer import MarkupRenderer
 
 
 class DocumentTraceHTMLGenerator:
@@ -13,19 +12,11 @@ class DocumentTraceHTMLGenerator:
     env.globals.update(isinstance=isinstance)
 
     @staticmethod
-    def export(config, document, traceability_index, link_renderer):
+    def export(
+        config, document, traceability_index, markup_renderer, link_renderer
+    ):
         output = ""
 
-        document_type = DocumentType.trace()
-
-        markup_renderer = MarkupRenderer.create(
-            document.config.markup,
-            traceability_index,
-            link_renderer,
-            document,
-            document_type,
-        )
-
         template = DocumentTraceHTMLGenerator.env.get_template(
             "single_document_traceability/document.jinja.html"
         )
@@ -40,7 +31,7 @@ class DocumentTraceHTMLGenerator:
             traceability_index=traceability_index,
             renderer=markup_renderer,
             link_renderer=link_renderer,
-            document_type=document_type,
+            document_type=DocumentType.trace(),
             standalone=False,
             root_path=root_path,
             static_path=static_path,
