@@ -2,11 +2,14 @@ import os
 from enum import Enum
 from functools import partial
 from pathlib import Path
+from typing import Optional
 
+from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.cli.cli_arg_parser import ExportCommandConfig
 from strictdoc.core.document_meta import DocumentMeta
 from strictdoc.core.document_tree import DocumentTree
 from strictdoc.core.source_tree import SourceTree
+from strictdoc.core.traceability_index import TraceabilityIndex
 from strictdoc.export.html.generators.document import DocumentHTMLGenerator
 from strictdoc.export.html.generators.document_deep_trace import (
     DocumentDeepTraceHTMLGenerator,
@@ -30,6 +33,7 @@ from strictdoc.export.html.generators.source_file_view_generator import (
     SourceFileViewHTMLGenerator,
 )
 from strictdoc.export.html.renderers.link_renderer import LinkRenderer
+from strictdoc.export.html.renderers.markup_renderer import MarkupRenderer
 from strictdoc.export.html.tools.html_embedded import HTMLEmbedder
 from strictdoc.helpers.file_modification_time import get_file_modification_time
 from strictdoc.helpers.file_system import sync_dir
@@ -52,14 +56,15 @@ class ExportMode(Enum):
 class HTMLGenerator:
     @staticmethod
     def export_tree(
+        *,
         config: ExportCommandConfig,
         document_tree: DocumentTree,
-        traceability_index,
+        traceability_index: TraceabilityIndex,
         output_html_root,
         strictdoc_last_update,
         asset_dirs,
         parallelizer,
-    ):
+    ):  # pylint: disable=too-many-arguments,too-many-statements
         if "html" in config.formats:
             if "html-standalone" in config.formats:
                 export_mode = ExportMode.DOCTREE_AND_STANDALONE
@@ -79,10 +84,10 @@ class HTMLGenerator:
         writer = DocumentTreeHTMLGenerator()
         output = writer.export(config, document_tree, traceability_index)
 
-        output_html_static_files = "{}/_static".format(output_html_root)
-        output_file = "{}/index.html".format(output_html_root)
+        output_html_static_files = os.path.join(output_html_root, "_static")
+        output_file = os.path.join(output_html_root, "index.html")
 
-        with open(output_file, "w") as file:
+        with open(output_file, "w", encoding="utf8") as file:
             file.write(output)
 
         static_files_src = os.path.join(
@@ -109,11 +114,54 @@ class HTMLGenerator:
             )
             sync_dir(source_path, destination_path)
 
+        document: Document
+        for document in document_tree.document_list:
+            # If a document file exists we want to check its modification path
+            # in order to skip its generation in case it has not changed since
+            # the last generation. We also check the Traceability Index for the
+            # document's dependencies to see if they must be regenerated as
+            # well.
+            document_meta_or_none: Optional[DocumentMeta] = document.meta
+            assert document_meta_or_none is not None
+            document_meta: DocumentMeta = document_meta_or_none
+            full_output_path = os.path.join(
+                export_options.strictdoc_src_path,
+                document_meta.get_html_doc_path(),
+            )
+            if not os.path.isfile(full_output_path):
+                document.ng_needs_generation = True
+            else:
+                output_file_mtime = get_file_modification_time(full_output_path)
+                sdoc_mtime = get_file_modification_time(
+                    document_meta.input_doc_full_path
+                )
+                if not (
+                    sdoc_mtime < output_file_mtime
+                    and export_options.strictdoc_last_update < output_file_mtime
+                ):
+                    document.ng_needs_generation = True
+            if document.ng_needs_generation:
+                todo_list = [document]
+                finished = set()
+                while todo_list:
+                    document = todo_list.pop()
+                    if document in finished:
+                        continue
+                    document.ng_needs_generation = True
+                    document_parents = traceability_index.get_document_parents(
+                        document
+                    )
+                    document_children = (
+                        traceability_index.get_document_children(document)
+                    )
+                    todo_list.extend(document_parents)
+                    todo_list.extend(document_children)
+                    finished.add(document)
+
         export_binding = partial(
             HTMLGenerator._export_with_performance,
             config,
             export_options=export_options,
-            document_tree=document_tree,
             traceability_index=traceability_index,
             link_renderer=link_renderer,
         )
@@ -131,13 +179,18 @@ class HTMLGenerator:
         output_html_requirements_coverage = os.path.join(
             output_html_root, "requirements_coverage.html"
         )
-        with open(output_html_requirements_coverage, "w") as file:
+        with open(
+            output_html_requirements_coverage, "w", encoding="utf8"
+        ) as file:
             file.write(requirements_coverage_content)
 
         if config.experimental_enable_file_traceability:
             assert isinstance(document_tree.source_tree, SourceTree)
-            print("Generating source files")
+            print("Generating source files:")
             for source_file in document_tree.source_tree.source_files:
+                if not source_file.is_referenced:
+                    continue
+
                 with measure_performance(
                     f"File: {source_file.in_doctree_source_file_rel_path}"
                 ):
@@ -146,11 +199,12 @@ class HTMLGenerator:
                     )
                     document_content = SourceFileViewHTMLGenerator.export(
                         source_file,
-                        document_tree,
                         traceability_index,
                         link_renderer,
                     )
-                    with open(source_file.output_file_full_path, "w") as file:
+                    with open(
+                        source_file.output_file_full_path, "w", encoding="utf-8"
+                    ) as file:
                         file.write(document_content)
 
             source_coverage_content = SourceFileCoverageHTMLGenerator.export(
@@ -162,13 +216,14 @@ class HTMLGenerator:
             output_html_source_coverage = os.path.join(
                 output_html_root, "source_coverage.html"
             )
-            with open(output_html_source_coverage, "w") as file:
+            with open(
+                output_html_source_coverage, "w", encoding="utf8"
+            ) as file:
                 file.write(source_coverage_content)
 
         print(
-            "Export completed. Documentation tree can be found at:\n{}".format(
-                output_html_root
-            )
+            "Export completed. Documentation tree can be found at:\n"
+            f"{output_html_root}"
         )
 
     @staticmethod
@@ -176,47 +231,27 @@ class HTMLGenerator:
         config: ExportCommandConfig,
         document,
         export_options: ExportOptions,
-        document_tree,
         traceability_index,
         link_renderer,
     ):
-        document_meta: DocumentMeta = document.meta
-        full_output_path = os.path.join(
-            export_options.strictdoc_src_path, document_meta.get_html_doc_path()
-        )
-
-        # If file exists we want to check its modification path in order to skip
-        # its generation in case it has not changed since the last generation.
-        if os.path.isfile(full_output_path):
-            output_file_mtime = get_file_modification_time(full_output_path)
-            sdoc_mtime = get_file_modification_time(
-                document_meta.input_doc_full_path
-            )
-
-            if (
-                sdoc_mtime < output_file_mtime
-                and export_options.strictdoc_last_update < output_file_mtime
-            ):
-                with measure_performance("Skip: {}".format(document.name)):
-                    return
-
-        with measure_performance("Published: {}".format(document.name)):
+        if not document.ng_needs_generation:
+            with measure_performance(f"Skip: {document.name}"):
+                return
+        with measure_performance(f"Published: {document.name}"):
             HTMLGenerator._export(
                 config,
                 export_options.export_mode,
                 document,
-                document_tree,
                 traceability_index,
                 link_renderer,
             )
-        return None
+        return
 
     @staticmethod
     def _export(
         config: ExportCommandConfig,
         export_mode,
         document,
-        document_tree,
         traceability_index,
         link_renderer,
     ):
@@ -225,69 +260,84 @@ class HTMLGenerator:
         document_output_folder = document_meta.output_document_dir_full_path
         Path(document_output_folder).mkdir(parents=True, exist_ok=True)
 
-        if (
-            export_mode == ExportMode.DOCTREE
-            or export_mode == ExportMode.DOCTREE_AND_STANDALONE
+        markup_renderer = MarkupRenderer.create(
+            document.config.markup,
+            traceability_index,
+            link_renderer,
+            document,
+        )
+
+        if export_mode in (
+            ExportMode.DOCTREE,
+            ExportMode.DOCTREE_AND_STANDALONE,
         ):
             # Single Document pages
             document_content = DocumentHTMLGenerator.export(
                 config,
-                document_tree,
                 document,
                 traceability_index,
+                markup_renderer,
                 link_renderer,
+                standalone=False,
             )
-
             document_out_file = document_meta.get_html_doc_path()
-            with open(document_out_file, "w") as file:
+            with open(document_out_file, "w", encoding="utf8") as file:
                 file.write(document_content)
 
             # Single Document Table pages
             document_content = DocumentTableHTMLGenerator.export(
-                config, document, traceability_index, link_renderer
+                config,
+                document,
+                traceability_index,
+                markup_renderer,
+                link_renderer,
             )
             document_out_file = document_meta.get_html_table_path()
-
-            with open(document_out_file, "w") as file:
+            with open(document_out_file, "w", encoding="utf8") as file:
                 file.write(document_content)
 
             # Single Document Traceability pages
             document_content = DocumentTraceHTMLGenerator.export(
-                config, document, traceability_index, link_renderer
+                config,
+                document,
+                traceability_index,
+                markup_renderer,
+                link_renderer,
             )
             document_out_file = document_meta.get_html_traceability_path()
-
-            with open(document_out_file, "w") as file:
+            with open(document_out_file, "w", encoding="utf8") as file:
                 file.write(document_content)
 
             # Single Document Deep Traceability pages
             document_content = DocumentDeepTraceHTMLGenerator.export_deep(
-                config, document, traceability_index, link_renderer
+                config,
+                document,
+                traceability_index,
+                markup_renderer,
+                link_renderer,
             )
             document_out_file = document_meta.get_html_deep_traceability_path()
-
-            with open(document_out_file, "w") as file:
+            with open(document_out_file, "w", encoding="utf8") as file:
                 file.write(document_content)
 
-        if (
-            export_mode == ExportMode.STANDALONE
-            or export_mode == ExportMode.DOCTREE_AND_STANDALONE
+        if export_mode in (
+            ExportMode.STANDALONE,
+            ExportMode.DOCTREE_AND_STANDALONE,
         ):
             # Single Document pages (standalone)
             document_content = DocumentHTMLGenerator.export(
                 config,
-                document_tree,
                 document,
                 traceability_index,
+                markup_renderer,
                 link_renderer,
                 standalone=True,
             )
-
             document_out_file = document_meta.get_html_doc_standalone_path()
             document_content_with_embedded_assets = HTMLEmbedder.embed_assets(
                 document_content, document_out_file
             )
-            with open(document_out_file, "w") as file:
+            with open(document_out_file, "w", encoding="utf8") as file:
                 file.write(document_content_with_embedded_assets)
 
         return document
